@@ -22,11 +22,11 @@ class UserSerializer(serializers.ModelSerializer):
     security_pin = serializers.CharField(source='extended_user.security_pin', allow_null=True, required=False)
     security_qr = serializers.CharField(source='extended_user.security_qr', allow_null=True, required=False)
     city_name = serializers.CharField(source='extended_user.city.name', read_only=True)
-    city = serializers.IntegerField(source='extended_user.city_id')
+    city = serializers.IntegerField(source='extended_user.city_id', allow_null=True, required=True)
     alias = serializers.CharField(source='extended_user.alias', allow_null=True, required=False)
     gender = serializers.CharField(source='extended_user.gender', allow_null=True, required=False)
     registration = serializers.BooleanField(default=False, allow_null=True, required=False)
-    #encrypted = serializers.BooleanField(default=False, allow_null=True, required=False)
+    # encrypted = serializers.BooleanField(default=False, allow_null=True, required=False)
     multi_sessions = serializers.NullBooleanField(
         source='extended_user.multi_sessions',
         default=False
@@ -38,7 +38,9 @@ class UserSerializer(serializers.ModelSerializer):
     )
     date_of_birth = serializers.DateField(
         source='extended_user.date_of_birth', format="%Y-%m-%d",
-        input_formats=['%Y-%m-%dT%H:%M:%S.%fZ', 'iso-8601']
+        input_formats=['%Y-%m-%dT%H:%M:%S.%fZ', 'iso-8601'],
+        allow_null=True,
+        required=True
     )
 
     def get_profile_image_url(self, obj):  # pragma: no cover
@@ -72,7 +74,7 @@ class UserSerializer(serializers.ModelSerializer):
             'is_staff',
             'password',
             'username',
-            #'encrypted',
+            # 'encrypted',
             'last_login',
             'date_joined',
             'alias',
